import { I as IntermediaryMessageTypes, M as MAGIC, e as Subject, B as BehaviorSubject, d as StorageEvent, R as REGION, O as OffscreenToBackgroundEvent, j as BackgroundToContentScriptEvent, k as ACTIVE_TAB_KEY, F as FULL_VERSION, H as HELP_URL, l as ActionType, m as fromEvent, P as PopupToBackgroundEvent, a as ContentScriptToBackgroundEvent, n as APP_ID_KEY, b as CommonEvent, o as StashFileType } from './event-BS8SI8SU.js';
import { a as getSharedStorage, s as setupWebExtensionOAuth, e as createFetch, i as instance, j as RecorderDB, l as RecorderStateInitialValue, m as syncRecorderState, n as RecordingStatus, g as getSessionStorage, o as syncStorage, r as recordStop, p as resetTasks, q as getClientId, t as publicFetch, u as SelectElementActionType, v as stashFileContent, x as FileStatus, y as clearCompletedTask } from './fetch-FElFJLmr.js';
import { b as browser } from './browser-polyfill-IrS90NOa.js';
import { b as createFingerprint, c as createEndpointRuntime, d as decodeConnectionArgs, f as formatEndpoint, p as parseEndpoint, a as createStreamWirings, e as createDeliveryLogger, P as PortMessage } from './chunk-VCGWCGR7-C3l0TXSv.js';
import './interval-DGm5uo8I.js';

function setupTelemetry(context, toIntermediary$) {
    async function logError(message, extension) {
        toIntermediary$.next([
            {
                type: IntermediaryMessageTypes.Log,
                magic: MAGIC,
                level: 'error',
                message,
                extension,
                context
            }
        ]);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function logErrorObject(msg, error) {
        console.error(msg, error);
        logError(msg, {
            message: error?.message ?? String(error),
            stack: error?.stack
        });
    }
    return {
        logError,
        logErrorObject
    };
}

var pendingResponses = createDeliveryLogger();
var connMap = /* @__PURE__ */ new Map();
var oncePortConnectedCbs = /* @__PURE__ */ new Map();
var onceSessionEndCbs = /* @__PURE__ */ new Map();
var oncePortConnected = (endpointName, cb) => {
  oncePortConnectedCbs.set(
    endpointName,
    (oncePortConnectedCbs.get(endpointName) || /* @__PURE__ */ new Set()).add(cb)
  );
  return () => {
    const su = oncePortConnectedCbs.get(endpointName);
    if ((su == null ? void 0 : su.delete(cb)) && (su == null ? void 0 : su.size) === 0)
      oncePortConnectedCbs.delete(endpointName);
  };
};
var onceSessionEnded = (sessionFingerprint, cb) => {
  onceSessionEndCbs.set(
    sessionFingerprint,
    (onceSessionEndCbs.get(sessionFingerprint) || /* @__PURE__ */ new Set()).add(cb)
  );
};
var notifyEndpoint = (endpoint) => ({
  withFingerprint: (fingerprint) => {
    const nextChain = (v) => ({ and: () => v });
    const notifications = {
      aboutIncomingMessage: (message) => {
        const recipient = connMap.get(endpoint);
        PortMessage.toExtensionContext(recipient.port, {
          status: "incoming",
          message
        });
        return nextChain(notifications);
      },
      aboutSuccessfulDelivery: (receipt) => {
        const sender = connMap.get(endpoint);
        PortMessage.toExtensionContext(sender.port, {
          status: "delivered",
          receipt
        });
        return nextChain(notifications);
      },
      aboutMessageUndeliverability: (resolvedDestination, message) => {
        const sender = connMap.get(endpoint);
        if ((sender == null ? void 0 : sender.fingerprint) === fingerprint) {
          PortMessage.toExtensionContext(sender.port, {
            status: "undeliverable",
            resolvedDestination,
            message
          });
        }
        return nextChain(notifications);
      },
      whenDeliverableTo: (targetEndpoint) => {
        const notifyDeliverability = () => {
          const origin = connMap.get(endpoint);
          if ((origin == null ? void 0 : origin.fingerprint) === fingerprint && connMap.has(targetEndpoint)) {
            PortMessage.toExtensionContext(origin.port, {
              status: "deliverable",
              deliverableTo: targetEndpoint
            });
            return true;
          }
        };
        if (!notifyDeliverability()) {
          const unsub = oncePortConnected(targetEndpoint, notifyDeliverability);
          onceSessionEnded(fingerprint, unsub);
        }
        return nextChain(notifications);
      },
      aboutSessionEnded: (endedSessionFingerprint) => {
        const conn = connMap.get(endpoint);
        if ((conn == null ? void 0 : conn.fingerprint) === fingerprint) {
          PortMessage.toExtensionContext(conn.port, {
            status: "terminated",
            fingerprint: endedSessionFingerprint
          });
        }
        return nextChain(notifications);
      }
    };
    return notifications;
  }
});
var sessFingerprint = createFingerprint();
var endpointRuntime = createEndpointRuntime(
  "background",
  (message) => {
    var _a;
    if (message.origin.context === "background" && ["content-script", "devtools "].includes(message.destination.context) && !message.destination.tabId) {
      throw new TypeError(
        "When sending messages from background page, use @tabId syntax to target specific tab"
      );
    }
    const resolvedSender = formatEndpoint({
      ...message.origin,
      ...message.origin.context === "window" && { context: "content-script" }
    });
    const resolvedDestination = formatEndpoint({
      ...message.destination,
      ...message.destination.context === "window" && {
        context: "content-script"
      },
      tabId: message.destination.tabId || message.origin.tabId
    });
    message.destination.tabId = null;
    message.destination.frameId = null;
    const dest = () => connMap.get(resolvedDestination);
    const sender = () => connMap.get(resolvedSender);
    const deliver = () => {
      var _a2;
      notifyEndpoint(resolvedDestination).withFingerprint(dest().fingerprint).aboutIncomingMessage(message);
      const receipt = {
        message,
        to: dest().fingerprint,
        from: {
          endpointId: resolvedSender,
          fingerprint: (_a2 = sender()) == null ? void 0 : _a2.fingerprint
        }
      };
      if (message.messageType === "message")
        pendingResponses.add(receipt);
      if (message.messageType === "reply")
        pendingResponses.remove(message.messageID);
      if (sender()) {
        notifyEndpoint(resolvedSender).withFingerprint(sender().fingerprint).aboutSuccessfulDelivery(receipt);
      }
    };
    if ((_a = dest()) == null ? void 0 : _a.port) {
      deliver();
    } else if (message.messageType === "message") {
      if (message.origin.context === "background") {
        oncePortConnected(resolvedDestination, deliver);
      } else if (sender()) {
        notifyEndpoint(resolvedSender).withFingerprint(sender().fingerprint).aboutMessageUndeliverability(resolvedDestination, message).and().whenDeliverableTo(resolvedDestination);
      }
    }
  },
  (message) => {
    const resolvedSender = formatEndpoint({
      ...message.origin,
      ...message.origin.context === "window" && { context: "content-script" }
    });
    const sender = connMap.get(resolvedSender);
    const receipt = {
      message,
      to: sessFingerprint,
      from: {
        endpointId: resolvedSender,
        fingerprint: sender.fingerprint
      }
    };
    notifyEndpoint(resolvedSender).withFingerprint(sender.fingerprint).aboutSuccessfulDelivery(receipt);
  }
);
browser.runtime.onConnect.addListener((incomingPort) => {
  var _a;
  const connArgs = decodeConnectionArgs(incomingPort.name);
  if (!connArgs)
    return;
  connArgs.endpointName || (connArgs.endpointName = formatEndpoint({
    context: "content-script",
    tabId: incomingPort.sender.tab.id,
    frameId: incomingPort.sender.frameId
  }));
  const { tabId: linkedTabId, frameId: linkedFrameId } = parseEndpoint(
    connArgs.endpointName
  );
  connMap.set(connArgs.endpointName, {
    fingerprint: connArgs.fingerprint,
    port: incomingPort
  });
  (_a = oncePortConnectedCbs.get(connArgs.endpointName)) == null ? void 0 : _a.forEach((cb) => cb());
  oncePortConnectedCbs.delete(connArgs.endpointName);
  onceSessionEnded(connArgs.fingerprint, () => {
    const rogueMsgs = pendingResponses.entries().filter((pendingMessage) => pendingMessage.to === connArgs.fingerprint);
    pendingResponses.remove(rogueMsgs);
    rogueMsgs.forEach((rogueMessage) => {
      if (rogueMessage.from.endpointId === "background") {
        endpointRuntime.endTransaction(rogueMessage.message.transactionId);
      } else {
        notifyEndpoint(rogueMessage.from.endpointId).withFingerprint(rogueMessage.from.fingerprint).aboutSessionEnded(connArgs.fingerprint);
      }
    });
  });
  incomingPort.onDisconnect.addListener(() => {
    var _a2, _b;
    if (((_a2 = connMap.get(connArgs.endpointName)) == null ? void 0 : _a2.fingerprint) === connArgs.fingerprint)
      connMap.delete(connArgs.endpointName);
    (_b = onceSessionEndCbs.get(connArgs.fingerprint)) == null ? void 0 : _b.forEach((cb) => cb());
    onceSessionEndCbs.delete(connArgs.fingerprint);
  });
  incomingPort.onMessage.addListener((msg) => {
    var _a2, _b;
    if (msg.type === "sync") {
      const allActiveSessions = [...connMap.values()].map(
        (conn) => conn.fingerprint
      );
      const stillPending = msg.pendingResponses.filter(
        (fp) => allActiveSessions.includes(fp.to)
      );
      pendingResponses.add(...stillPending);
      msg.pendingResponses.filter(
        (deliveryReceipt) => !allActiveSessions.includes(deliveryReceipt.to)
      ).forEach(
        (deliveryReceipt) => notifyEndpoint(connArgs.endpointName).withFingerprint(connArgs.fingerprint).aboutSessionEnded(deliveryReceipt.to)
      );
      msg.pendingDeliveries.forEach(
        (intendedDestination) => notifyEndpoint(connArgs.endpointName).withFingerprint(connArgs.fingerprint).whenDeliverableTo(intendedDestination)
      );
      return;
    }
    if (msg.type === "deliver" && ((_b = (_a2 = msg.message) == null ? void 0 : _a2.origin) == null ? void 0 : _b.context)) {
      msg.message.origin.tabId = linkedTabId;
      msg.message.origin.frameId = linkedFrameId;
      endpointRuntime.handleMessage(msg.message);
    }
  });
});
var { sendMessage, onMessage } = endpointRuntime;
createStreamWirings(endpointRuntime);

const toIntermediary$ = new Subject();
const { logErrorObject } = setupTelemetry('background', toIntermediary$);

const corsRuleForTab = async (tabId)=>{
    const tab = await browser.tabs.get(tabId);
    if (!tab.url) {
        return;
    }
    const url = new URL(tab.url);
    const existingRules = await browser.declarativeNetRequest.getSessionRules();
    let maxId = 0;
    existingRules.forEach((rule)=>{
        if (rule.id > maxId) {
            maxId = rule.id;
        }
    });
    await browser.declarativeNetRequest.updateSessionRules({
        addRules: [
            {
                id: maxId + 1,
                priority: 1,
                condition: {
                    tabIds: [
                        tabId
                    ]
                },
                action: {
                    type: 'modifyHeaders',
                    responseHeaders: [
                        {
                            header: 'Access-Control-Allow-Origin',
                            operation: 'set',
                            value: url.origin
                        }
                    ]
                }
            }
        ]
    });
};
const removeAllRules = async ()=>{
    const rules = await browser.declarativeNetRequest.getSessionRules();
    const ids = rules.map((rule)=>rule.id);
    await browser.declarativeNetRequest.updateSessionRules({
        removeRuleIds: ids
    });
};
const removeRuleForTab = async (tabId)=>{
    const rules = await browser.declarativeNetRequest.getSessionRules();
    const ids = rules.filter((rule)=>rule.condition.tabIds?.includes(tabId)).map((rule)=>rule.id);
    await browser.declarativeNetRequest.updateSessionRules({
        removeRuleIds: ids
    });
};

const storage = getSharedStorage();
const { oauth } = setupWebExtensionOAuth(storage);
const $fetch = createFetch(storage, oauth, REGION);
const db = instance.resolve(RecorderDB);
const state$ = new BehaviorSubject(RecorderStateInitialValue);
const sync = syncRecorderState(state$);
sync.then(()=>{
    state$.subscribe(async (state)=>{
        if (state.status !== RecordingStatus.Running) {
            await removeAllRules();
        } else {
            const recordingTab = await getCurrentNormalWindowTab();
            if (recordingTab?.id) {
                await corsRuleForTab(recordingTab.id);
            }
        }
    });
});
async function getCurrentNormalWindowTab() {
    // `tab` will either be a `tabs.Tab` instance or `undefined`.
    const tabs = await browser.tabs.query({
        active: true,
        currentWindow: true,
        windowType: 'normal'
    });
    return tabs.at(0);
}
onMessage(StorageEvent.SetItem, (event)=>{
    const { key, value } = event.data;
    return storage.setItem(key, value);
});
onMessage(StorageEvent.GetItem, (event)=>{
    return storage.getItem(event.data);
});
onMessage(StorageEvent.HasItem, (event)=>{
    return storage.hasItem(event.data);
});
onMessage(StorageEvent.RemoveItem, (event)=>{
    return storage.removeItem(event.data);
});
onMessage(StorageEvent.Clear, ()=>{
    return storage.clear();
});
onMessage(StorageEvent.GetKeys, ()=>{
    return storage.getKeys();
});

const GENERIC_FONTS = [
    'cursive',
    'fantasy',
    'fixed',
    'sansserif',
    'serif',
    'standard'
];
function isTruthy(value) {
    return Boolean(value);
}
const OFFSCREEN_DOCUMENT_PATH = browser.runtime.getURL('src/pages/offscreen/index.html');
onMessage(OffscreenToBackgroundEvent.GenericFonts, ()=>{
    return Promise.all(GENERIC_FONTS.map((genericFamily)=>chrome.fontSettings.getFont({
            genericFamily
        }).then(({ fontId })=>[
                genericFamily,
                fontId
            ], ()=>undefined))).then((fonts)=>Object.fromEntries(fonts.filter(isTruthy)));
});
storage.watch((event, key)=>{
    sendMessage(StorageEvent.Change, {
        event,
        key
    }, 'offscreen');
});
async function loadOffscreenPage() {
    const contexts = await chrome.runtime.getContexts({
        contextTypes: [
            chrome.runtime.ContextType.OFFSCREEN_DOCUMENT
        ],
        documentUrls: [
            OFFSCREEN_DOCUMENT_PATH
        ]
    });
    if (contexts.length > 0) {
        return;
    }
    await chrome.offscreen.createDocument({
        justification: 'uploading',
        url: OFFSCREEN_DOCUMENT_PATH,
        reasons: [
            chrome.offscreen.Reason.BLOBS
        ]
    });
}

const LOGIN_STATE_KEY$1 = 'login-state';
const activeTab$ = new BehaviorSubject(null);
const session$1 = getSessionStorage();
syncStorage(activeTab$, session$1, ACTIVE_TAB_KEY, null);
browser.tabs.onActivated.addListener(async ({ tabId })=>{
    activeTab$.next(String(tabId));
    if (state$.getValue().status === RecordingStatus.Running) {
        corsRuleForTab(tabId);
    }
});
browser.tabs.onRemoved.addListener(async (tabId, { isWindowClosing })=>{
    if (state$.getValue().snapshotTabId === String(tabId)) {
        recordStop(state$, false);
    }
    await removeRuleForTab(tabId);
    if (isWindowClosing) {
        return;
    }
    const loginState = await session$1.getItem(LOGIN_STATE_KEY$1);
    if (!loginState || tabId !== loginState.tabId) {
        return;
    }
    session$1.removeItem(LOGIN_STATE_KEY$1);
    if (!loginState.restoreTab) {
        return;
    }
    try {
        const previousTab = await browser.tabs.get(loginState.restoreTab);
        if (!previousTab?.id) {
            return;
        }
        await browser.tabs.update(previousTab.id, {
            active: true
        });
        await sendMessage(BackgroundToContentScriptEvent.ShowDemoVideo, null, {
            context: 'content-script',
            tabId: previousTab.id
        });
    } catch (e) {
        console.error(e);
    }
});

/// <reference types="chrome" />
console.log('Extension Version', FULL_VERSION);
console.log('Development Page', browser.runtime.getURL('/src/pages/dev/index.html'));
const loadingOffscreen = loadOffscreenPage();
browser.runtime.onStartup.addListener(async ()=>{
    await resetTasks(db);
});
browser.runtime.onInstalled.addListener(async ({ reason })=>{
    if (reason === 'update') {
        try {
            await loadingOffscreen;
            await chrome.offscreen.closeDocument();
        } catch (error) {
        // noop
        }
        loadOffscreenPage();
    }
    await self.skipWaiting();
    session.clear();
    resetTasks(db);
    if (reason === 'install' && HELP_URL) {
        await browser.tabs.create({
            url: HELP_URL
        });
        const clientUserId = await getClientId();
        await publicFetch('/api/action-log/public', {
            method: 'POST',
            body: {
                actionType: ActionType.INSTALL_EXTENSION,
                data: {
                    clientUserId
                }
            }
        });
    }
});
// 有新版本的时候，强制更新
// https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/API/runtime/onUpdateAvailable#examples
// https://stackoverflow.com/questions/74635848/auto-update-in-chrome-extensions
// https://developer.chrome.com/docs/extensions/reference/api/runtime#event-onUpdateAvailable
browser.runtime.onUpdateAvailable.addListener((details)=>{
    console.log(details.version);
    // Proceed to upgrade the add-on
    browser.runtime.reload();
});
fromEvent(globalThis, 'error').subscribe((event)=>{
    logErrorObject(event.message, event.error);
});
const LOGIN_STATE_KEY = 'login-state';
const session = getSessionStorage();
onMessage(PopupToBackgroundEvent.Login, async ()=>{
    const activeTabs = await browser.tabs.query({
        active: true,
        currentWindow: true
    });
    const activeTab = activeTabs.at(0);
    const tab = await openNewTab(getLoginPage());
    await session.setItem(LOGIN_STATE_KEY, {
        tabId: tab.id,
        restoreTab: activeTab?.id
    });
});
onMessage(ContentScriptToBackgroundEvent.GetTabHref, async ({ sender })=>{
    const tab = await browser.tabs.get(sender.tabId);
    if (!tab || !tab.url) {
        return {
            href: ''
        };
    }
    return {
        href: tab.url
    };
});
onMessage(ContentScriptToBackgroundEvent.GetOAuthCode, async ()=>{
    const appId = await storage.getItem(APP_ID_KEY);
    const auth = await $fetch('/api/admin-user/code', {
        method: 'POST'
    });
    return {
        ...auth,
        appId
    };
});
onMessage(CommonEvent.StartRecord, async ({ data })=>{
    const { windowId, tabId } = data;
    const screenshot = await browser.tabs.captureVisibleTab(windowId, {
        format: 'png'
    });
    await sendMessage(BackgroundToContentScriptEvent.StartCountdown, data, {
        context: 'content-script',
        tabId
    });
    stashScreenshot(data, screenshot);
});
onMessage(ContentScriptToBackgroundEvent.GetFrameId, ({ sender })=>{
    return {
        frameId: sender.frameId
    };
});
onMessage(PopupToBackgroundEvent.SelectElementStart, async ({ data })=>{
    await browser.tabs.sendMessage(data.tabId, {
        ...data,
        type: PopupToBackgroundEvent.SelectElementStart
    });
});
onMessage(ContentScriptToBackgroundEvent.SelectElementAction, async ({ sender, data })=>{
    if (data.action === SelectElementActionType.Stop) {
        // send to all frames
        await browser.tabs.sendMessage(sender.tabId, {
            ...data,
            type: ContentScriptToBackgroundEvent.SelectElementAction
        });
    } else if (data.frameId) {
        // send to specific frame
        await browser.tabs.sendMessage(sender.tabId, {
            ...data,
            type: ContentScriptToBackgroundEvent.SelectElementAction
        }, {
            frameId: data.frameId
        });
    } else {
        // send to root frame
        await sendMessage(ContentScriptToBackgroundEvent.SelectElementAction, data, {
            context: 'content-script',
            tabId: sender.tabId
        });
    }
});
function getLoginPage() {
    return browser.runtime.getURL('/src/pages/login/index.html');
}
async function openNewTab(href) {
    return browser.tabs.create({
        url: href
    });
}
async function stashScreenshot(data, screenshot) {
    try {
        const { taskId, rect } = data;
        const timestamp = new Date().toISOString();
        const offscreen = await loadOffscreenPage();
        const url = 'screenshot';
        const file = await sendMessage(CommonEvent.TouchStashFile, {
            url,
            fileType: StashFileType.Screenshot,
            timestamp,
            taskId,
            contentType: 'image/png'
        }, 'offscreen');
        if (!file) {
            return;
        }
        const blob = await fetch(screenshot).then((res)=>res.blob()).then(cropImage(rect));
        const hash = await stashFileContent(taskId, url, blob, db);
        await sendMessage(CommonEvent.MarkFileStashed, {
            taskId,
            url,
            hash,
            contentType: blob.type,
            patch: false,
            status: FileStatus.Finished
        }, 'offscreen');
    } catch (e) {
        logErrorObject('start record fail', e);
    }
}
function cropImage(rect) {
    return async (blob)=>{
        const image = await createImageBitmap(blob);
        const scale = Math.min(1920 / image.width, 1080 / image.height);
        // 选取元素时，元素一部分可能在屏幕外面
        const areaWidth = rect ? Math.min(rect.width, image.width - rect.x) : image.width;
        const areaHeight = rect ? Math.min(rect.height, image.height - rect.y) : image.height;
        const width = areaWidth * scale;
        const height = areaHeight * scale;
        const canvas = new OffscreenCanvas(width, height);
        const ctx = canvas.getContext('2d');
        if (!ctx) {
            return blob;
        }
        if (rect) {
            ctx.drawImage(image, rect.x, rect.y, areaWidth, areaHeight, 0, 0, canvas.width, canvas.height);
        } else {
            ctx.drawImage(image, 0, 0, width, height);
        }
        // 使用webp上传封面图，libavif 太大，未来浏览器内置 avif 后考虑使用 avif
        return canvas.convertToBlob({
            type: 'image/webp',
            quality: 0.9
        });
    };
}

browser.runtime.onStartup.addListener(()=>{
    clearCompletedTask(db);
});
