import { R as RemoteUploaderService } from './el-result-b--j129v.js';
import { q as init_1, M as MessagePortSubject } from './index-B_buVPU_.js';
import { i as isSafeInteger, a as ContentScriptToBackgroundEvent, f as firstValueFrom, M as MAGIC, b as CommonEvent } from './event-BS8SI8SU.js';
import { g as getSessionStorage, r as recordStop, w as waitForClientConnect } from './fetch-FElFJLmr.js';
import { b as browser } from './browser-polyfill-IrS90NOa.js';
import { r as removeTabAvailable, s as setTabAvailable } from './tabs-Bd72S87K.js';
import { s as setupWebExtensionServer } from './server-DoNLbJ8S.js';
import { b as bridge } from './content-script-BpVBZO9g.js';
import './interval-DGm5uo8I.js';
import './switchMap-BFpIwZmz.js';
import './chunk-ODNERRIQ-AxWlbKXg.js';
import './chunk-VCGWCGR7-C3l0TXSv.js';

async function setupIntermediary(bridge) {
    if (!window.parent || window.parent === window) {
        return;
    }
    const { sendMessage } = bridge;
    const tab = await browser.tabs.getCurrent();
    const browserTabId = tab?.id;
    if (!isSafeInteger(browserTabId)) {
        throw new Error();
    }
    const tabId = String(browserTabId);
    const { frameId } = await sendMessage(ContentScriptToBackgroundEvent.GetFrameId, null, 'background');
    const createId = init_1({
        fingerprint: String(frameId)
    });
    const session = getSessionStorage();
    const { onClientConnect, ctx } = setupWebExtensionServer(tabId, {
        session,
        async startRecord (args) {
            const { windowId } = tab;
            if (!windowId) {
                return;
            }
            return await sendMessage(CommonEvent.StartRecord, {
                ...args,
                tabId: browserTabId,
                windowId
            });
        }
    });
    const { recorderState$, container } = ctx;
    RemoteUploaderService.register(container, bridge);
    const isRootFrame = window.top === window.parent;
    if (isRootFrame && recorderState$.getValue().snapshotTabId === String(tabId)) {
        recordStop(recorderState$, false);
    }
    firstValueFrom(waitForClientConnect()).then((event)=>{
        const port = event.ports[0];
        const message$ = new MessagePortSubject(port, String(tab.id));
        onClientConnect(createId(), message$);
        if (isRootFrame) {
            window.onbeforeunload = ()=>{
                removeTabAvailable(browserTabId, String(frameId));
                if (recorderState$.getValue().snapshotTabId === String(tabId)) {
                    recordStop(recorderState$, false);
                }
            };
            return setTabAvailable(browserTabId, String(frameId));
        }
        return undefined;
    });
    window.parent.postMessage(MAGIC, '*');
}

setupIntermediary(bridge);
