import { ax as Observable, bA as noop, bx as operate, ay as createOperatorSubscriber, bQ as isLocalhost, m as fromEvent, Y as map, a as ContentScriptToBackgroundEvent, bR as isDemoWayHost, bf as createDebug, e as Subject, bp as tap, bS as SELECT_ELEMENT_EVENT, bT as yt, bU as SelectElementActionType, i as isSafeInteger, a1 as filter, bV as Pt, bW as Vt, bX as Mt, $ as PopupToContentScriptEvent, j as BackgroundToContentScriptEvent, P as PopupToBackgroundEvent } from './event-BS8SI8SU.js';
import { bC as IOSubjectRPC, aE as IOSubject, bD as merge, bE as SELECT_ELEMENT_ATTRIBUTE_NAME } from './index-B_buVPU_.js';
import { s as switchMap } from './switchMap-BFpIwZmz.js';

var NEVER = new Observable(noop);

function takeWhile(predicate, inclusive) {
    return operate(function (source, subscriber) {
        var index = 0;
        source.subscribe(createOperatorSubscriber(subscriber, function (value) {
            var result = predicate(value, index++);
            (result || inclusive) && subscriber.next(value);
            !result && subscriber.complete();
        }));
    });
}

const FIGMA_MAGIC = '83031241-6f60-4576-b24e-d05b66728ca4';

function isHrefAllowed(href) {
    const url = new URL(href);
    return isDemoWayHost(url.hostname) || /^(.*\.)?(figma|mastergo)\.com$/.test(url.hostname) || isLocalhost(url.hostname);
}
async function setupBridge(bridge) {
    const url = new URL(location.href);
    if (!isLocalhost(url.hostname) && url.hostname !== 's.demoway.co' && url.hostname !== 's.dwimg.top' && url.searchParams.get('bridge') !== 'true') {
        return;
    }
    const { sendMessage } = bridge;
    const rpc = new IOSubjectRPC(FIGMA_MAGIC, new IOSubject((message)=>{
        window.parent.postMessage(message, '*');
    }, fromEvent(window, 'message').pipe(map((event)=>event.data))));
    const { href } = await sendMessage(ContentScriptToBackgroundEvent.GetTabHref, null, 'background');
    if (!href || !isHrefAllowed(href)) {
        return;
    }
    rpc.register('getOAuthCode', ()=>{
        return sendMessage(ContentScriptToBackgroundEvent.GetOAuthCode, null, 'background');
    });
    window.parent.postMessage(FIGMA_MAGIC, '*');
}

function setupSelectElement(frameId, bridge) {
    const debug = createDebug('recorder:select-element');
    const stop$ = new Subject();
    const pickElement$ = new Subject();
    /**
   * 当前鼠标元素
   */ let mouseTarget;
    /**
   * 放大缩小后的元素
   */ let candidate;
    const getEventBounding = (taskId, finish)=>(event)=>{
            if (!event.target || !Pt(event.target)) {
                return {
                    finish: true,
                    rect: null,
                    taskId
                };
            }
            let element;
            if (finish) {
                element = candidate || mouseTarget;
            }
            if (!element) {
                element = findEligibleElement(event.target);
            }
            if (!element) {
                return {
                    finish: true,
                    rect: null,
                    taskId
                };
            }
            if (!finish) {
                if (mouseTarget !== candidate) {
                    candidate = undefined;
                }
                mouseTarget = element;
            }
            if (finish) {
                element.setAttribute(SELECT_ELEMENT_ATTRIBUTE_NAME, String(taskId));
                debug('element selected', element);
            }
            return {
                finish,
                rect: element.getBoundingClientRect().toJSON(),
                taskId
            };
        };
    function stopSelectElement() {
        bridge.sendMessage(ContentScriptToBackgroundEvent.SelectElementAction, {
            action: SelectElementActionType.Stop,
            frameId
        }, 'background');
    }
    let preventContextMenu = false;
    fromEvent(window, 'contextmenu', {
        capture: true
    }).subscribe((event)=>{
        if (preventContextMenu) {
            preventContextMenu = false;
            event.preventDefault();
            event.stopPropagation();
        }
    });
    fromEvent(window, 'keydown', {
        capture: true
    }).subscribe((event)=>{
        if (event.key === 'Escape') {
            stopSelectElement();
            return;
        }
        if (!candidate && !mouseTarget) {
            return;
        }
        switch(event.key){
            case 'Shift':
                event.preventDefault();
                findParent();
                break;
            case 'Control':
                event.preventDefault();
                findChild();
                break;
            case ' ':
                event.preventDefault();
                submitCandidate();
                break;
        }
    });
    const manual$ = new Subject();
    const submit$ = new Subject();
    pickElement$.pipe(tap(()=>{
        candidate = undefined;
        mouseTarget = undefined;
    }), switchMap((taskId)=>{
        if (!isSafeInteger(taskId)) {
            return NEVER;
        }
        resetSelect();
        return merge(fromEvent(window, 'mouseover', {
            capture: true
        }).pipe(filter((event)=>isEligibleElement(event.target)), map(getEventBounding(taskId, false))), fromEvent(window, 'click', {
            capture: true
        }).pipe(filter((event)=>!!event.target && Pt(event.target) && !isIgnored(event.target)), tap((event)=>{
            event.preventDefault();
            event.stopPropagation();
        }), filter(isMainButton), tap((event)=>{
            if (event.buttons & 2) {
                preventContextMenu = true;
            }
        }), map(getEventBounding(taskId, true))), fromEvent(window, 'contextmenu', {
            capture: true
        }).pipe(tap((event)=>{
            event.preventDefault();
            event.stopPropagation();
            candidate = undefined;
        }), map((event)=>({
                ...getEventBounding(taskId, false)(event),
                anchor: {
                    x: event.x,
                    y: event.y
                }
            }))), stop$.pipe(map(()=>({
                rect: null,
                finish: true
            }))), manual$.pipe(tap((element)=>{
            candidate = element;
        }), map((element)=>{
            return {
                finish: false,
                rect: element.getBoundingClientRect(),
                taskId,
                anchor: 'keep'
            };
        })), submit$.pipe(tap((element)=>{
            element.setAttribute(SELECT_ELEMENT_ATTRIBUTE_NAME, String(taskId));
        }), map((element)=>{
            return {
                finish: true,
                rect: element.getBoundingClientRect(),
                taskId
            };
        }))).pipe(takeWhile((event)=>!event.finish, true));
    })).subscribe((value)=>{
        submitPickElement({
            ...value,
            frameId
        });
    });
    function submitPickElement(value) {
        if (!window.parent || window.parent === window) {
            window.dispatchEvent(new CustomEvent(SELECT_ELEMENT_EVENT, {
                detail: JSON.stringify(value)
            }));
        } else {
            window.parent.postMessage({
                type: SELECT_ELEMENT_EVENT,
                ...value
            }, '*');
        }
        if (value.finish) {
            stopSelectElement();
        }
    }
    fromEvent(window, 'message').subscribe((event)=>{
        if (event.data?.type !== SELECT_ELEMENT_EVENT) {
            return;
        }
        const { rect } = event.data;
        if (!rect) {
            return;
        }
        const iframes = document.getElementsByTagName('iframe');
        let iframe;
        for(let i = 0; i < iframes.length; i++){
            const item = iframes.item(i);
            if (!item) {
                continue;
            }
            if (item.contentWindow === event.source) {
                iframe = item;
                break;
            }
        }
        if (!iframe) {
            return;
        }
        const transformed = yt(rect, [
            iframe
        ]);
        submitPickElement({
            ...event.data,
            rect: transformed.toJSON()
        });
    });
    function resetSelect() {
        const elements = document.querySelectorAll(`[${SELECT_ELEMENT_ATTRIBUTE_NAME}]`);
        for(let i = 0; i < elements.length; i++){
            const element = elements.item(0);
            if (!element) {
                continue;
            }
            element.removeAttribute(SELECT_ELEMENT_ATTRIBUTE_NAME);
        }
    }
    function isIgnored(element) {
        return element.matches('[data-demoway-ignore], [data-demoway-ignore] *');
    }
    function isEligibleElement(element) {
        if (!element || !Pt(element)) {
            return false;
        }
        if (isIgnored(element)) {
            return false;
        }
        const rect = element.getBoundingClientRect();
        if (!rect.width || !rect.height) {
            return false;
        }
        return !Vt(element) || element.tagName === 'svg';
    }
    const RECT_KEYS = [
        'width',
        'height'
    ];
    function isSameSize(a, b) {
        const b1 = a.getBoundingClientRect();
        const b2 = b.getBoundingClientRect();
        return RECT_KEYS.every((key)=>b1[key].toFixed(2) === b2[key].toFixed(2));
    }
    function findEligibleElement(element) {
        let target = element;
        while(target !== document.body && target.parentElement && (!isEligibleElement(target) || isSameSize(target, target.parentElement))){
            target = target.parentElement;
        }
        return target;
    }
    // function isSecondaryButton(event: MouseEvent): boolean {
    //   return event.button === 2;
    // }
    function isMainButton(event) {
        return event.button === 0;
    }
    function findParent() {
        const current = candidate ?? mouseTarget;
        if (!current || current === document.body || !current.parentElement || current.parentElement === document.body) {
            return;
        }
        const element = findEligibleElement(current.parentElement);
        if (element) {
            manual$.next(element);
        }
    }
    function findChild() {
        const current = candidate;
        const mouse = mouseTarget;
        if (!current || !mouse || current === mouse) {
            return;
        }
        const hierarchy = Mt(mouse, current);
        if (hierarchy[0]) {
            manual$.next(hierarchy[0]);
        } else {
            manual$.next(mouse);
        }
    }
    function submitCandidate() {
        const current = candidate ?? mouseTarget;
        if (current) {
            submit$.next(current);
        }
    }
    function start(taskId) {
        pickElement$.next(taskId);
    }
    function stop() {
        stop$.next();
    }
    return {
        findParent,
        findChild,
        submitCandidate,
        start,
        stop
    };
}

const debug = createDebug('demoway:content-script');
function setupIsolatedWorld(bridge, browser) {
    const { onMessage } = bridge;
    setupBridge(bridge);
    if (!window.parent || window.parent === window) {
        onMessage(PopupToContentScriptEvent.RecordingCompleted, async ({ data })=>{
            debug('receive message %s', PopupToContentScriptEvent.RecordingCompleted, data);
            window.dispatchEvent(new CustomEvent(PopupToContentScriptEvent.RecordingCompleted, {
                detail: JSON.stringify(data)
            }));
        });
        onMessage(PopupToContentScriptEvent.ShowTourTutorialVideo, async ()=>{
            debug('receive message %s', PopupToContentScriptEvent.ShowTourTutorialVideo);
            window.dispatchEvent(new CustomEvent(PopupToContentScriptEvent.ShowTourTutorialVideo));
        });
        onMessage(BackgroundToContentScriptEvent.StartCountdown, ({ data })=>{
            debug('receive message %s', BackgroundToContentScriptEvent.StartCountdown, data);
            window.dispatchEvent(new CustomEvent(BackgroundToContentScriptEvent.StartCountdown, {
                detail: JSON.stringify(data)
            }));
        });
        onMessage(BackgroundToContentScriptEvent.ShowDemoVideo, ()=>{
            debug('receive message %s', BackgroundToContentScriptEvent.ShowDemoVideo);
            window.dispatchEvent(new CustomEvent(BackgroundToContentScriptEvent.ShowDemoVideo));
        });
    }
    {
        bridge.sendMessage(ContentScriptToBackgroundEvent.GetFrameId, null).then(({ frameId })=>{
            const { start, stop, findChild, findParent, submitCandidate } = setupSelectElement(frameId, bridge);
            function onReceiveAction(action) {
                switch(action){
                    case SelectElementActionType.Stop:
                        stop();
                        break;
                    case SelectElementActionType.Submit:
                        submitCandidate();
                        break;
                    case SelectElementActionType.ZoomIn:
                        findChild();
                        break;
                    case SelectElementActionType.ZoomOut:
                        findParent();
                        break;
                }
            }
            onMessage(ContentScriptToBackgroundEvent.SelectElementAction, ({ data })=>{
                onReceiveAction(data.action);
            });
            browser.runtime.onMessage.addListener(async (raw)=>{
                const event = raw;
                switch(event.type){
                    case PopupToBackgroundEvent.SelectElementStart:
                        window.focus();
                        start(event.taskId);
                        break;
                    case ContentScriptToBackgroundEvent.SelectElementAction:
                        onReceiveAction(event.action);
                        break;
                }
            });
        });
    }
}

export { setupIsolatedWorld as s };
