import './el-result-b--j129v.js';
import { d as defineComponent, r as ref, u as useI18n, a as useSubscription, c as computed, b as useMutation, e as useLazyQuery, w as watch, o as openBlock, f as createElementBlock, t as toDisplayString, g as unref, h as createCommentVNode, i as createBlock, j as withCtx, k as createVNode, l as createTextVNode, F as Fragment, m as createBaseVNode, n as renderList, p as createApp } from './index-B_buVPU_.js';
import { E as EnvDocument, A as AppIdDocument, S as SetAppIdDocument, L as LoginByCodeDocument, U as UserProfileDocument, G as GRANT_TYPE, R as REGION, g as getAppOrigin, C as CLIENT_ID } from './event-BS8SI8SU.js';
import { c as checkAppId } from './fetch-FElFJLmr.js';
import { b as browser } from './browser-polyfill-IrS90NOa.js';
import { E as ElButton, a as ElResult, b as ElAvatar, c as ElOption, d as ElSelect, e as commonProvider } from './common-provider-CCqMHVZB.js';
import './interval-DGm5uo8I.js';
import './context-CuoyyfJD.js';
import './server-DoNLbJ8S.js';

const _hoisted_1 = {
    class: "flex flex-col items-center justify-center"
};
const _hoisted_2 = {
    key: 0
};
const _hoisted_3 = {
    class: "flex flex-col items-center"
};
const _hoisted_4 = {
    key: 1,
    class: "flex flex-col items-center mt-24 w-[240px]"
};
const _hoisted_5 = {
    class: "w-full text-center text-xl font-normal"
};
const _hoisted_6 = {
    class: "flex items-center"
};
const _sfc_main$1 = /*@__PURE__*/ defineComponent({
    __name: 'login',
    setup (__props) {
        const message = ref();
        const error = ref();
        const success = ref(false);
        const { t, locale } = useI18n();
        const appSelected = ref(false);
        const envSubscription = useSubscription(EnvDocument);
        const env = computed(()=>envSubscription.result.value?.env);
        const appIdSubscription = useSubscription(AppIdDocument);
        const appIdMutation = useMutation(SetAppIdDocument);
        const appId = computed({
            get () {
                return appIdSubscription.result.value?.appId;
            },
            set (value) {
                if (!value) {
                    return;
                }
                appIdMutation.mutate({
                    value
                });
            }
        });
        const loginByCodeMutation = useMutation(LoginByCodeDocument);
        const profileQuery = useLazyQuery(UserProfileDocument, {}, {
            fetchPolicy: 'network-only',
            nextFetchPolicy: 'network-only'
        });
        const applications = computed(()=>profileQuery.result.value?.profile?.applications ?? []);
        function getRandomValues() {
            const array = new Uint32Array(1);
            return window.crypto?.getRandomValues(array);
        }
        // state: https://developers.google.com/identity/openid-connect/openid-connect?hl=en#createxsrftoken
        function getSignUrl() {
            const env = envSubscription.result.value?.env;
            const origin = getAppOrigin(env || 'production');
            const url = new URL('/oauth', origin);
            url.searchParams.set('client_id', CLIENT_ID);
            url.searchParams.set('redirect_uri', browser.identity.getRedirectURL());
            url.searchParams.set('scope', 'extension');
            url.searchParams.set('state', String(getRandomValues()));
            url.searchParams.set('prompt', 'login');
            url.searchParams.set('lang', locale.value);
            if (GRANT_TYPE) {
                url.searchParams.set('grant_type', GRANT_TYPE);
            }
            return url.href;
        }
        function resizeAuthWindowOnCreated(width, height) {
            browser.windows.onCreated.addListener(function resizePopup(win) {
                if (win && win.id) {
                    // get current auth win pos, or default to center of screen
                    const { top: t = Math.round(window.screen.height / 2), left: l = Math.round(window.screen.width / 2), width: w = 0, height: h = 0 } = win;
                    // Resize and re-center the auth window
                    const opts = {
                        top: Math.round(t + h / 2 - height / 2),
                        left: Math.round(l + w / 2 - width / 2),
                        width,
                        height
                    };
                    browser.windows.update(win.id, opts);
                    browser.windows.onCreated.removeListener(resizePopup);
                }
            }, {
                windowTypes: [
                    'popup'
                ]
            });
        }
        let triggered = false;
        async function login() {
            if (triggered) {
                return;
            }
            triggered = true;
            const signUrl = getSignUrl();
            // console.debug('signUrl', signUrl);
            try {
                resizeAuthWindowOnCreated(550, 800);
                const redirectUrl = await browser.identity.launchWebAuthFlow({
                    url: signUrl,
                    interactive: true
                });
                if (!redirectUrl) {
                    return;
                }
                const url = new URL(redirectUrl);
                const searchParams = url.searchParams;
                const code = searchParams.get('code');
                if (!code) {
                    throw new Error();
                }
                const result = await loginByCodeMutation.mutate({
                    code
                });
                await (profileQuery.load() || profileQuery.refetch());
                const profile = profileQuery.result.value?.profile;
                if (GRANT_TYPE === 'figma') {
                    if (!profile?.figmaAppId) {
                        throw new Error('Missing figma app info');
                    }
                    checkAppId(profile.figmaAppId, REGION, async ()=>{
                        return profile.id;
                    }, {
                        from: 'profile.figmaAppId',
                        profile: profile
                    });
                    await appIdMutation.mutate({
                        value: profile.figmaAppId
                    });
                } else if (profile?.applications?.length) {
                    checkAppId(profile.applications[0].id, REGION, async ()=>{
                        return profile.id;
                    }, {
                        from: 'profile.applications[0].id',
                        profile: profile
                    });
                    await appIdMutation.mutate({
                        value: profile.applications[0].id
                    });
                }
                if (profile?.applications?.length === 1) {
                    appSelected.value = true;
                }
                success.value = result?.data?.login ?? false;
            } catch (err) {
                message.value = t('camera.Login.error');
                error.value = err?.toString() || '';
                console.error(err);
            }
        }
        const close = ()=>{
            window.close();
        };
        const stop = watch(envSubscription.loading, (loading)=>{
            if (loading) {
                return;
            }
            stop();
            login();
        });
        return (_ctx, _cache)=>{
            const _component_el_button = ElButton;
            const _component_el_result = ElResult;
            const _component_el_avatar = ElAvatar;
            const _component_el_option = ElOption;
            const _component_el_select = ElSelect;
            return openBlock(), createElementBlock("div", _hoisted_1, [
                env.value && env.value !== 'production' ? (openBlock(), createElementBlock("h1", _hoisted_2, toDisplayString(unref(envSubscription).result.value?.env), 1)) : createCommentVNode("", true),
                error.value ? (openBlock(), createBlock(_component_el_result, {
                    key: 1,
                    icon: "error",
                    title: message.value,
                    "sub-title": error.value
                }, {
                    extra: withCtx(()=>[
                            createVNode(_component_el_button, {
                                type: "primary",
                                onClick: close
                            }, {
                                default: withCtx(()=>[
                                        createTextVNode(toDisplayString(unref(t)('common.buttons.close')), 1)
                                    ]),
                                _: 1
                            })
                        ]),
                    _: 1
                }, 8, [
                    "title",
                    "sub-title"
                ])) : createCommentVNode("", true),
                success.value ? (openBlock(), createElementBlock(Fragment, {
                    key: 2
                }, [
                    appSelected.value ? (openBlock(), createBlock(_component_el_result, {
                        key: 0,
                        icon: "success",
                        title: unref(t)('camera.Login.success'),
                        "sub-title": unref(t)('camera.Login.subTitle')
                    }, {
                        extra: withCtx(()=>[
                                createBaseVNode("div", _hoisted_3, [
                                    createVNode(_component_el_button, {
                                        type: "primary",
                                        onClick: close
                                    }, {
                                        default: withCtx(()=>[
                                                createTextVNode(toDisplayString(unref(t)('common.buttons.close')), 1)
                                            ]),
                                        _: 1
                                    })
                                ])
                            ]),
                        _: 1
                    }, 8, [
                        "title",
                        "sub-title"
                    ])) : (openBlock(), createElementBlock("div", _hoisted_4, [
                        createBaseVNode("h2", _hoisted_5, toDisplayString(unref(t)('common.selectApp')), 1),
                        createVNode(_component_el_select, {
                            modelValue: appId.value,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event)=>appId.value = $event),
                            class: "my-4 w-full"
                        }, {
                            default: withCtx(()=>[
                                    (openBlock(true), createElementBlock(Fragment, null, renderList(applications.value, (item)=>{
                                        return openBlock(), createBlock(_component_el_option, {
                                            key: item.id,
                                            label: item.name,
                                            value: item.id
                                        }, {
                                            default: withCtx(()=>[
                                                    createBaseVNode("div", _hoisted_6, [
                                                        createVNode(_component_el_avatar, {
                                                            class: "mr-1",
                                                            size: 16,
                                                            src: item.avatar
                                                        }, null, 8, [
                                                            "src"
                                                        ]),
                                                        createBaseVNode("span", null, toDisplayString(item.name), 1)
                                                    ])
                                                ]),
                                            _: 2
                                        }, 1032, [
                                            "label",
                                            "value"
                                        ]);
                                    }), 128))
                                ]),
                            _: 1
                        }, 8, [
                            "modelValue"
                        ]),
                        createVNode(_component_el_button, {
                            type: "primary",
                            onClick: _cache[1] || (_cache[1] = ($event)=>appSelected.value = true)
                        }, {
                            default: withCtx(()=>[
                                    createTextVNode(toDisplayString(_ctx.$t('common.buttons.confirm')), 1)
                                ]),
                            _: 1
                        })
                    ]))
                ], 64)) : createCommentVNode("", true)
            ]);
        };
    }
});

const _sfc_main = /*@__PURE__*/ defineComponent({
    __name: 'login-page',
    setup (__props) {
        return (_ctx, _cache)=>{
            return openBlock(), createBlock(_sfc_main$1);
        };
    }
});

function setupLoginPage() {
    createApp(_sfc_main).use(commonProvider()).mount('#app');
}

setupLoginPage();
