import { L as LoggerService } from './el-result-b--j129v.js';
import './index-B_buVPU_.js';
import { d as StorageEvent, O as OffscreenToBackgroundEvent, e as Subject, R as REGION, t as taskStatusBroadcast, b as CommonEvent, h as ENV_KEY } from './event-BS8SI8SU.js';
import { d as defineDriver, b as createStorage, s as setupWebExtensionOAuth, e as createFetch, i as instance, S as STORAGE, F as FETCH, L as LOGGER, f as FONT_SETTINGS_SERVICE, R as REGION$1, U as UploaderService, h as FilesService, j as RecorderDB, k as storageObservable } from './fetch-FElFJLmr.js';
import './browser-polyfill-IrS90NOa.js';
import { c as createPersistentPort } from './chunk-ODNERRIQ-AxWlbKXg.js';
import { c as createEndpointRuntime, a as createStreamWirings } from './chunk-VCGWCGR7-C3l0TXSv.js';
import './interval-DGm5uo8I.js';

const UnstorageDriverWebextBridge = defineDriver((opts)=>{
    const { bridge, change$ } = opts;
    const { sendMessage } = bridge;
    return {
        name: 'storage.rpc',
        options: opts,
        hasItem (key) {
            return sendMessage(StorageEvent.HasItem, key, 'background');
        },
        getItem (key) {
            return sendMessage(StorageEvent.GetItem, key, 'background');
        },
        setItem (key, value) {
            return sendMessage(StorageEvent.SetItem, {
                key,
                value
            }, 'background');
        },
        removeItem (key) {
            return sendMessage(StorageEvent.RemoveItem, key, 'background');
        },
        getKeys () {
            return sendMessage(StorageEvent.GetKeys, null, 'background');
        },
        clear () {
            return sendMessage(StorageEvent.Clear, null, 'background');
        },
        watch (callback) {
            const subscription = change$.subscribe(({ event, key })=>{
                callback(event, key);
            });
            return ()=>{
                subscription.unsubscribe();
            };
        }
    };
});

class OffscreenPageFontSettingsService {
    bridge;
    constructor(bridge){
        this.bridge = bridge;
    }
    getGenericFontFamilyFonts() {
        return this.bridge.sendMessage(OffscreenToBackgroundEvent.GenericFonts, null);
    }
}

async function setupOffscreenPage(bridge) {
    const { onMessage } = bridge;
    const change$ = new Subject();
    const storage = createStorage({
        driver: UnstorageDriverWebextBridge({
            bridge,
            change$
        })
    });
    const { oauth } = setupWebExtensionOAuth(storage);
    const $fetch = createFetch(storage, oauth, REGION);
    const env$ = storageObservable(storage, ENV_KEY);
    const logger = new LoggerService(oauth, storage, REGION);
    env$.subscribe((env)=>{
        logger.setEnv(env || 'production');
    });
    const fontSettingsService = new OffscreenPageFontSettingsService(bridge);
    instance.register(STORAGE, {
        useValue: storage
    }).register(FETCH, {
        useValue: $fetch
    }).register(LOGGER, {
        useValue: logger
    }).register(FONT_SETTINGS_SERVICE, {
        useValue: fontSettingsService
    }).register(REGION$1, {
        useValue: REGION
    });
    const uploaderService = instance.resolve(UploaderService);
    const filesService = instance.resolve(FilesService);
    uploaderService.taskStatusChange$.subscribe((event)=>{
        taskStatusBroadcast.postMessage(event);
    });
    onMessage(CommonEvent.UploadTask, async (event)=>{
        await uploaderService.uploadTask(event.data);
    });
    onMessage(CommonEvent.CancelTask, async (event)=>{
        await uploaderService.cancelTask(event.data);
    });
    onMessage(StorageEvent.Change, (event)=>{
        change$.next(event.data);
    });
    onMessage(CommonEvent.TouchStashFile, (event)=>{
        return filesService.touchStashFile(event.data);
    });
    onMessage(CommonEvent.MarkFileStashed, (event)=>{
        return filesService.markFileStashed(event.data);
    });
    onMessage(CommonEvent.GetTaskUploadStatus, (event)=>{
        return filesService.getFileStashStatus(event.data, undefined);
    });
    window.__db = instance.resolve(RecorderDB);
}

// src/offscreen.ts
var port = createPersistentPort("offscreen");
var endpointRuntime = createEndpointRuntime(
  "offscreen",
  (message) => port.postMessage(message)
);
port.onMessage(endpointRuntime.handleMessage);
var { sendMessage, onMessage } = endpointRuntime;
var { openStream, onOpenStreamChannel } = createStreamWirings(endpointRuntime);

const bridge = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
  __proto__: null,
  onMessage,
  onOpenStreamChannel,
  openStream,
  sendMessage
}, Symbol.toStringTag, { value: 'Module' }));

setupOffscreenPage(bridge);
