import { R as REGION, k as ACTIVE_TAB_KEY, m as fromEvent, t as taskStatusBroadcast, Y as map, h as ENV_KEY } from './event-BS8SI8SU.js';
import { a as getSharedStorage, g as getSessionStorage, s as setupWebExtensionOAuth, e as createFetch, X as setupServer, Y as OAUTH_CLIENT, Z as OAUTH_CONTROLLER, m as syncRecorderState, o as syncStorage, k as storageObservable, _ as RecorderClientTransport } from './fetch-FElFJLmr.js';
import './browser-polyfill-IrS90NOa.js';
import { L as LoggerService } from './el-result-b--j129v.js';

function setupWebExtensionServer(tabId, init) {
    const storage = getSharedStorage();
    const session = getSessionStorage();
    const { oauth, oauthClient } = setupWebExtensionOAuth(storage);
    const env$ = storageObservable(storage, ENV_KEY);
    const $fetch = createFetch(storage, oauth, REGION);
    const logger = new LoggerService(oauth, storage, REGION);
    env$.subscribe((env)=>{
        logger.setEnv(env || 'production');
    });
    const { ctx } = setupServer('browser_extension', storage, tabId, logger, $fetch, REGION);
    ctx.container.register(OAUTH_CLIENT, {
        useValue: oauthClient
    }).register(OAUTH_CONTROLLER, {
        useValue: oauth
    });
    const ready = Promise.all([
        syncRecorderState(ctx.recorderState$),
        syncStorage(ctx.activeTab$, session, ACTIVE_TAB_KEY, null)
    ]);
    function onClientConnect(documentId, message$) {
        const client = new RecorderClientTransport(message$, {
            ...ctx,
            ...init,
            tabId
        });
        client.onConnectAck(documentId);
        return client;
    }
    fromEvent(taskStatusBroadcast, 'message').pipe(map((event)=>event.data)).subscribe(ctx.taskStatusChange$);
    ctx.logout$.subscribe(()=>{
        oauth.logout();
    });
    return {
        ctx,
        onClientConnect,
        ready,
        oauth,
        logger
    };
}

export { setupWebExtensionServer as s };
