const __vite__wasmUrl = "/assets/thunder_wasm_bg-CYKZS25g.wasm";

const __vite__initWasm = async (opts = {}, url) => {
    let result;
    if (url.startsWith("data:")) {
        const urlContent = url.replace(/^data:.*?base64,/, "");
        let bytes;
        if (typeof Buffer === "function" && typeof Buffer.from === "function") {
            bytes = Buffer.from(urlContent, "base64");
        }
        else if (typeof atob === "function") {
            const binaryString = atob(urlContent);
            bytes = new Uint8Array(binaryString.length);
            for (let i = 0; i < binaryString.length; i++) {
                bytes[i] = binaryString.charCodeAt(i);
            }
        }
        else {
            throw new Error("Cannot decode base64-encoded data URL");
        }
        result = await WebAssembly.instantiate(bytes, opts);
    }
    else {
        // https://github.com/mdn/webassembly-examples/issues/5
        // WebAssembly.instantiateStreaming requires the server to provide the
        // correct MIME type for .wasm files, which unfortunately doesn't work for
        // a lot of static file servers, so we just work around it by getting the
        // raw buffer.
        // @ts-ignore
        const response = await fetch(url);
        const contentType = response.headers.get("Content-Type") || "";
        if ("instantiateStreaming" in WebAssembly && contentType.startsWith("application/wasm")) {
            result = await WebAssembly.instantiateStreaming(response, opts);
        }
        else {
            const buffer = await response.arrayBuffer();
            result = await WebAssembly.instantiate(buffer, opts);
        }
    }
    return result.instance.exports;
};

function commonjsRequire(path) {
	throw new Error('Could not dynamically require "' + path + '". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.');
}

let wasm$1;
function __wbg_set_wasm(val) {
    wasm$1 = val;
}


const lTextDecoder = typeof TextDecoder === 'undefined' ? (commonjsRequire)('util').TextDecoder : TextDecoder;

let cachedTextDecoder = new lTextDecoder('utf-8', { ignoreBOM: true, fatal: true });

cachedTextDecoder.decode();

let cachedUint8ArrayMemory0 = null;

function getUint8ArrayMemory0() {
    if (cachedUint8ArrayMemory0 === null || cachedUint8ArrayMemory0.byteLength === 0) {
        cachedUint8ArrayMemory0 = new Uint8Array(wasm$1.memory.buffer);
    }
    return cachedUint8ArrayMemory0;
}

function getStringFromWasm0(ptr, len) {
    ptr = ptr >>> 0;
    return cachedTextDecoder.decode(getUint8ArrayMemory0().subarray(ptr, ptr + len));
}

let WASM_VECTOR_LEN = 0;

const lTextEncoder = typeof TextEncoder === 'undefined' ? (commonjsRequire)('util').TextEncoder : TextEncoder;

let cachedTextEncoder = new lTextEncoder('utf-8');

const encodeString = (typeof cachedTextEncoder.encodeInto === 'function'
    ? function (arg, view) {
    return cachedTextEncoder.encodeInto(arg, view);
}
    : function (arg, view) {
    const buf = cachedTextEncoder.encode(arg);
    view.set(buf);
    return {
        read: arg.length,
        written: buf.length
    };
});

function passStringToWasm0(arg, malloc, realloc) {

    if (realloc === undefined) {
        const buf = cachedTextEncoder.encode(arg);
        const ptr = malloc(buf.length, 1) >>> 0;
        getUint8ArrayMemory0().subarray(ptr, ptr + buf.length).set(buf);
        WASM_VECTOR_LEN = buf.length;
        return ptr;
    }

    let len = arg.length;
    let ptr = malloc(len, 1) >>> 0;

    const mem = getUint8ArrayMemory0();

    let offset = 0;

    for (; offset < len; offset++) {
        const code = arg.charCodeAt(offset);
        if (code > 0x7F) break;
        mem[ptr + offset] = code;
    }

    if (offset !== len) {
        if (offset !== 0) {
            arg = arg.slice(offset);
        }
        ptr = realloc(ptr, len, len = offset + arg.length * 3, 1) >>> 0;
        const view = getUint8ArrayMemory0().subarray(ptr + offset, ptr + len);
        const ret = encodeString(arg, view);

        offset += ret.written;
        ptr = realloc(ptr, len, offset, 1) >>> 0;
    }

    WASM_VECTOR_LEN = offset;
    return ptr;
}

function isLikeNone(x) {
    return x === undefined || x === null;
}

let cachedDataViewMemory0 = null;

function getDataViewMemory0() {
    if (cachedDataViewMemory0 === null || cachedDataViewMemory0.buffer.detached === true || (cachedDataViewMemory0.buffer.detached === undefined && cachedDataViewMemory0.buffer !== wasm$1.memory.buffer)) {
        cachedDataViewMemory0 = new DataView(wasm$1.memory.buffer);
    }
    return cachedDataViewMemory0;
}

function debugString(val) {
    // primitive types
    const type = typeof val;
    if (type == 'number' || type == 'boolean' || val == null) {
        return  `${val}`;
    }
    if (type == 'string') {
        return `"${val}"`;
    }
    if (type == 'symbol') {
        const description = val.description;
        if (description == null) {
            return 'Symbol';
        } else {
            return `Symbol(${description})`;
        }
    }
    if (type == 'function') {
        const name = val.name;
        if (typeof name == 'string' && name.length > 0) {
            return `Function(${name})`;
        } else {
            return 'Function';
        }
    }
    // objects
    if (Array.isArray(val)) {
        const length = val.length;
        let debug = '[';
        if (length > 0) {
            debug += debugString(val[0]);
        }
        for(let i = 1; i < length; i++) {
            debug += ', ' + debugString(val[i]);
        }
        debug += ']';
        return debug;
    }
    // Test for built-in
    const builtInMatches = /\[object ([^\]]+)\]/.exec(toString.call(val));
    let className;
    if (builtInMatches.length > 1) {
        className = builtInMatches[1];
    } else {
        // Failed to match the standard '[object ClassName]'
        return toString.call(val);
    }
    if (className == 'Object') {
        // we're a user defined class or Object
        // JSON.stringify avoids problems with cycles, and is generally much
        // easier than looping through ownProperties of `val`.
        try {
            return 'Object(' + JSON.stringify(val) + ')';
        } catch (_) {
            return 'Object';
        }
    }
    // errors
    if (val instanceof Error) {
        return `${val.name}: ${val.message}\n${val.stack}`;
    }
    // TODO we could test for more things here, like `Set`s and `Map`s.
    return className;
}

function takeFromExternrefTable0(idx) {
    const value = wasm$1.__wbindgen_export_2.get(idx);
    wasm$1.__externref_table_dealloc(idx);
    return value;
}

function _assertClass(instance, klass) {
    if (!(instance instanceof klass)) {
        throw new Error(`expected instance of ${klass.name}`);
    }
    return instance.ptr;
}
/**
 * @param {CSSCompiler} compiler
 * @param {string} base
 * @param {UrlBlocker} blocker
 * @returns {any}
 */
function stash_files$1(compiler, base, blocker) {
    _assertClass(compiler, CSSCompiler);
    const ptr0 = passStringToWasm0(base, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
    const len0 = WASM_VECTOR_LEN;
    _assertClass(blocker, UrlBlocker);
    const ret = wasm$1.stash_files(compiler.__wbg_ptr, ptr0, len0, blocker.__wbg_ptr);
    if (ret[2]) {
        throw takeFromExternrefTable0(ret[1]);
    }
    return takeFromExternrefTable0(ret[0]);
}

function notDefined(what) { return () => { throw new Error(`${what} is not defined`); }; }

function addToExternrefTable0(obj) {
    const idx = wasm$1.__externref_table_alloc();
    wasm$1.__wbindgen_export_2.set(idx, obj);
    return idx;
}

function handleError(f, args) {
    try {
        return f.apply(this, args);
    } catch (e) {
        const idx = addToExternrefTable0(e);
        wasm$1.__wbindgen_exn_store(idx);
    }
}

const CSSCompilerFinalization = (typeof FinalizationRegistry === 'undefined')
    ? { register: () => {}, unregister: () => {} }
    : new FinalizationRegistry(ptr => wasm$1.__wbg_csscompiler_free(ptr >>> 0, 1));

class CSSCompiler {

    __destroy_into_raw() {
        const ptr = this.__wbg_ptr;
        this.__wbg_ptr = 0;
        CSSCompilerFinalization.unregister(this);
        return ptr;
    }

    free() {
        const ptr = this.__destroy_into_raw();
        wasm$1.__wbg_csscompiler_free(ptr, 0);
    }
    /**
     * @param {any} config_input
     */
    constructor(config_input) {
        const ret = wasm$1.csscompiler_new(config_input);
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        this.__wbg_ptr = ret[0] >>> 0;
        CSSCompilerFinalization.register(this, this.__wbg_ptr, this);
        return this;
    }
    /**
     * @param {FilesProvider} provider
     * @returns {any}
     */
    patch_and_get_demo_dependencies(provider) {
        _assertClass(provider, FilesProvider);
        const ret = wasm$1.csscompiler_patch_and_get_demo_dependencies(this.__wbg_ptr, provider.__wbg_ptr);
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        return takeFromExternrefTable0(ret[0]);
    }
    /**
     * @param {any} value
     */
    patch(value) {
        const ret = wasm$1.csscompiler_patch(this.__wbg_ptr, value);
        if (ret[1]) {
            throw takeFromExternrefTable0(ret[0]);
        }
    }
    /**
     * @param {any} input
     * @returns {any}
     */
    get_delta_rules(input) {
        const ret = wasm$1.csscompiler_get_delta_rules(this.__wbg_ptr, input);
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        return takeFromExternrefTable0(ret[0]);
    }
    /**
     * @returns {any}
     */
    to_css() {
        const ret = wasm$1.csscompiler_to_css(this.__wbg_ptr);
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        return takeFromExternrefTable0(ret[0]);
    }
}

const FilesProviderFinalization = (typeof FinalizationRegistry === 'undefined')
    ? { register: () => {}, unregister: () => {} }
    : new FinalizationRegistry(ptr => wasm$1.__wbg_filesprovider_free(ptr >>> 0, 1));

class FilesProvider {

    __destroy_into_raw() {
        const ptr = this.__wbg_ptr;
        this.__wbg_ptr = 0;
        FilesProviderFinalization.unregister(this);
        return ptr;
    }

    free() {
        const ptr = this.__destroy_into_raw();
        wasm$1.__wbg_filesprovider_free(ptr, 0);
    }
    /**
     * @param {any} files_input
     */
    constructor(files_input) {
        const ret = wasm$1.filesprovider_new(files_input);
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        this.__wbg_ptr = ret[0] >>> 0;
        FilesProviderFinalization.register(this, this.__wbg_ptr, this);
        return this;
    }
    /**
     * @param {any} files_input
     */
    set_files(files_input) {
        const ret = wasm$1.filesprovider_set_files(this.__wbg_ptr, files_input);
        if (ret[1]) {
            throw takeFromExternrefTable0(ret[0]);
        }
    }
}

const UrlBlockerFinalization = (typeof FinalizationRegistry === 'undefined')
    ? { register: () => {}, unregister: () => {} }
    : new FinalizationRegistry(ptr => wasm$1.__wbg_urlblocker_free(ptr >>> 0, 1));

class UrlBlocker {

    __destroy_into_raw() {
        const ptr = this.__wbg_ptr;
        this.__wbg_ptr = 0;
        UrlBlockerFinalization.unregister(this);
        return ptr;
    }

    free() {
        const ptr = this.__destroy_into_raw();
        wasm$1.__wbg_urlblocker_free(ptr, 0);
    }
    constructor() {
        const ret = wasm$1.urlblocker_new();
        if (ret[2]) {
            throw takeFromExternrefTable0(ret[1]);
        }
        this.__wbg_ptr = ret[0] >>> 0;
        UrlBlockerFinalization.register(this, this.__wbg_ptr, this);
        return this;
    }
    /**
     * @param {string} url
     * @param {string} source_url
     * @param {string} request_type
     * @returns {boolean}
     */
    should_ignore(url, source_url, request_type) {
        const ptr0 = passStringToWasm0(url, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
        const len0 = WASM_VECTOR_LEN;
        const ptr1 = passStringToWasm0(source_url, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
        const len1 = WASM_VECTOR_LEN;
        const ptr2 = passStringToWasm0(request_type, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
        const len2 = WASM_VECTOR_LEN;
        const ret = wasm$1.urlblocker_should_ignore(this.__wbg_ptr, ptr0, len0, ptr1, len1, ptr2, len2);
        return ret !== 0;
    }
}

function __wbindgen_error_new(arg0, arg1) {
    const ret = new Error(getStringFromWasm0(arg0, arg1));
    return ret;
}
function __wbindgen_is_undefined(arg0) {
    const ret = arg0 === undefined;
    return ret;
}
function __wbindgen_in(arg0, arg1) {
    const ret = arg0 in arg1;
    return ret;
}
function __wbindgen_is_bigint(arg0) {
    const ret = typeof(arg0) === 'bigint';
    return ret;
}
function __wbindgen_bigint_from_u64(arg0) {
    const ret = BigInt.asUintN(64, arg0);
    return ret;
}
function __wbindgen_jsval_eq(arg0, arg1) {
    const ret = arg0 === arg1;
    return ret;
}
function __wbindgen_is_string(arg0) {
    const ret = typeof(arg0) === 'string';
    return ret;
}
function __wbindgen_string_get(arg0, arg1) {
    const obj = arg1;
    const ret = typeof(obj) === 'string' ? obj : undefined;
    var ptr1 = isLikeNone(ret) ? 0 : passStringToWasm0(ret, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
    var len1 = WASM_VECTOR_LEN;
    getDataViewMemory0().setInt32(arg0 + 4 * 1, len1, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, ptr1, true);
}
function __wbindgen_is_object(arg0) {
    const val = arg0;
    const ret = typeof(val) === 'object' && val !== null;
    return ret;
}
function __wbindgen_string_new(arg0, arg1) {
    const ret = getStringFromWasm0(arg0, arg1);
    return ret;
}
const __wbg_debug_a0b6c2c5ac9a4bfd = typeof console.debug == 'function' ? console.debug : notDefined('console.debug');

const __wbg_error_4d17c5bb1ca90c94 = typeof console.error == 'function' ? console.error : notDefined('console.error');

const __wbg_info_1c7fba7da21072d1 = typeof console.info == 'function' ? console.info : notDefined('console.info');

const __wbg_log_4de37a0274d94769 = typeof console.log == 'function' ? console.log : notDefined('console.log');

const __wbg_warn_2e2787d40aad9a81 = typeof console.warn == 'function' ? console.warn : notDefined('console.warn');

function __wbindgen_jsval_loose_eq(arg0, arg1) {
    const ret = arg0 == arg1;
    return ret;
}
function __wbindgen_boolean_get(arg0) {
    const v = arg0;
    const ret = typeof(v) === 'boolean' ? (v ? 1 : 0) : 2;
    return ret;
}
function __wbindgen_number_get(arg0, arg1) {
    const obj = arg1;
    const ret = typeof(obj) === 'number' ? obj : undefined;
    getDataViewMemory0().setFloat64(arg0 + 8 * 1, isLikeNone(ret) ? 0 : ret, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, !isLikeNone(ret), true);
}
function __wbindgen_as_number(arg0) {
    const ret = +arg0;
    return ret;
}
function __wbg_String_b9412f8799faab3e(arg0, arg1) {
    const ret = String(arg1);
    const ptr1 = passStringToWasm0(ret, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
    const len1 = WASM_VECTOR_LEN;
    getDataViewMemory0().setInt32(arg0 + 4 * 1, len1, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, ptr1, true);
}
function __wbindgen_number_new(arg0) {
    const ret = arg0;
    return ret;
}
function __wbg_getwithrefkey_edc2c8960f0f1191(arg0, arg1) {
    const ret = arg0[arg1];
    return ret;
}
function __wbg_set_f975102236d3c502(arg0, arg1, arg2) {
    arg0[arg1] = arg2;
}
function __wbg_get_5419cf6b954aa11d(arg0, arg1) {
    const ret = arg0[arg1 >>> 0];
    return ret;
}
function __wbg_length_f217bbbf7e8e4df4(arg0) {
    const ret = arg0.length;
    return ret;
}
function __wbg_new_034f913e7636e987() {
    const ret = new Array();
    return ret;
}
function __wbindgen_is_function(arg0) {
    const ret = typeof(arg0) === 'function';
    return ret;
}
function __wbg_new_7a87a0376e40533b() {
    const ret = new Map();
    return ret;
}
function __wbg_next_13b477da1eaa3897(arg0) {
    const ret = arg0.next;
    return ret;
}
function __wbg_next_b06e115d1b01e10b() { return handleError(function (arg0) {
    const ret = arg0.next();
    return ret;
}, arguments) }
function __wbg_done_983b5ffcaec8c583(arg0) {
    const ret = arg0.done;
    return ret;
}
function __wbg_value_2ab8a198c834c26a(arg0) {
    const ret = arg0.value;
    return ret;
}
function __wbg_iterator_695d699a44d6234c() {
    const ret = Symbol.iterator;
    return ret;
}
function __wbg_get_ef828680c64da212() { return handleError(function (arg0, arg1) {
    const ret = Reflect.get(arg0, arg1);
    return ret;
}, arguments) }
function __wbg_call_a9ef466721e824f2() { return handleError(function (arg0, arg1) {
    const ret = arg0.call(arg1);
    return ret;
}, arguments) }
function __wbg_new_e69b5f66fda8f13c() {
    const ret = new Object();
    return ret;
}
function __wbg_set_425e70f7c64ac962(arg0, arg1, arg2) {
    arg0[arg1 >>> 0] = arg2;
}
function __wbg_from_91a67a5f04c98a54(arg0) {
    const ret = Array.from(arg0);
    return ret;
}
function __wbg_isArray_6f3b47f09adb61b5(arg0) {
    const ret = Array.isArray(arg0);
    return ret;
}
function __wbg_instanceof_ArrayBuffer_74945570b4a62ec7(arg0) {
    let result;
    try {
        result = arg0 instanceof ArrayBuffer;
    } catch (_) {
        result = false;
    }
    const ret = result;
    return ret;
}
function __wbg_set_277a63e77c89279f(arg0, arg1, arg2) {
    const ret = arg0.set(arg1, arg2);
    return ret;
}
function __wbg_isSafeInteger_b9dff570f01a9100(arg0) {
    const ret = Number.isSafeInteger(arg0);
    return ret;
}
function __wbg_entries_c02034de337d3ee2(arg0) {
    const ret = Object.entries(arg0);
    return ret;
}
function __wbg_buffer_ccaed51a635d8a2d(arg0) {
    const ret = arg0.buffer;
    return ret;
}
function __wbg_newwithbyteoffsetandlength_7e3eb787208af730(arg0, arg1, arg2) {
    const ret = new Uint8Array(arg0, arg1 >>> 0, arg2 >>> 0);
    return ret;
}
function __wbg_new_fec2611eb9180f95(arg0) {
    const ret = new Uint8Array(arg0);
    return ret;
}
function __wbg_set_ec2fcf81bc573fd9(arg0, arg1, arg2) {
    arg0.set(arg1, arg2 >>> 0);
}
function __wbg_length_9254c4bd3b9f23c4(arg0) {
    const ret = arg0.length;
    return ret;
}
function __wbg_instanceof_Uint8Array_df0761410414ef36(arg0) {
    let result;
    try {
        result = arg0 instanceof Uint8Array;
    } catch (_) {
        result = false;
    }
    const ret = result;
    return ret;
}
function __wbg_new_abda76e883ba8a5f() {
    const ret = new Error();
    return ret;
}
function __wbg_stack_658279fe44541cf6(arg0, arg1) {
    const ret = arg1.stack;
    const ptr1 = passStringToWasm0(ret, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
    const len1 = WASM_VECTOR_LEN;
    getDataViewMemory0().setInt32(arg0 + 4 * 1, len1, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, ptr1, true);
}
function __wbg_error_f851667af71bcfc6(arg0, arg1) {
    let deferred0_0;
    let deferred0_1;
    try {
        deferred0_0 = arg0;
        deferred0_1 = arg1;
        console.error(getStringFromWasm0(arg0, arg1));
    } finally {
        wasm$1.__wbindgen_free(deferred0_0, deferred0_1, 1);
    }
}
function __wbindgen_bigint_get_as_i64(arg0, arg1) {
    const v = arg1;
    const ret = typeof(v) === 'bigint' ? v : undefined;
    getDataViewMemory0().setBigInt64(arg0 + 8 * 1, isLikeNone(ret) ? BigInt(0) : ret, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, !isLikeNone(ret), true);
}
function __wbindgen_debug_string(arg0, arg1) {
    const ret = debugString(arg1);
    const ptr1 = passStringToWasm0(ret, wasm$1.__wbindgen_malloc, wasm$1.__wbindgen_realloc);
    const len1 = WASM_VECTOR_LEN;
    getDataViewMemory0().setInt32(arg0 + 4 * 1, len1, true);
    getDataViewMemory0().setInt32(arg0 + 4 * 0, ptr1, true);
}
function __wbindgen_throw(arg0, arg1) {
    throw new Error(getStringFromWasm0(arg0, arg1));
}
function __wbindgen_memory() {
    const ret = wasm$1.memory;
    return ret;
}
function __wbindgen_init_externref_table() {
    const table = wasm$1.__wbindgen_export_2;
    const offset = table.grow(4);
    table.set(0, undefined);
    table.set(offset + 0, undefined);
    table.set(offset + 1, null);
    table.set(offset + 2, true);
    table.set(offset + 3, false);
}

URL = globalThis.URL;
const __vite__wasmModule = await __vite__initWasm({ "./thunder_wasm_bg.js": { __wbindgen_error_new: __wbindgen_error_new, __wbindgen_is_undefined: __wbindgen_is_undefined, __wbindgen_in: __wbindgen_in, __wbindgen_is_bigint: __wbindgen_is_bigint, __wbindgen_bigint_from_u64: __wbindgen_bigint_from_u64, __wbindgen_jsval_eq: __wbindgen_jsval_eq, __wbindgen_is_string: __wbindgen_is_string, __wbindgen_string_get: __wbindgen_string_get, __wbindgen_is_object: __wbindgen_is_object, __wbindgen_string_new: __wbindgen_string_new, __wbg_debug_a0b6c2c5ac9a4bfd: __wbg_debug_a0b6c2c5ac9a4bfd, __wbg_error_4d17c5bb1ca90c94: __wbg_error_4d17c5bb1ca90c94, __wbg_info_1c7fba7da21072d1: __wbg_info_1c7fba7da21072d1, __wbg_log_4de37a0274d94769: __wbg_log_4de37a0274d94769, __wbg_warn_2e2787d40aad9a81: __wbg_warn_2e2787d40aad9a81, __wbindgen_jsval_loose_eq: __wbindgen_jsval_loose_eq, __wbindgen_boolean_get: __wbindgen_boolean_get, __wbindgen_number_get: __wbindgen_number_get, __wbindgen_as_number: __wbindgen_as_number, __wbg_String_b9412f8799faab3e: __wbg_String_b9412f8799faab3e, __wbindgen_number_new: __wbindgen_number_new, __wbg_getwithrefkey_edc2c8960f0f1191: __wbg_getwithrefkey_edc2c8960f0f1191, __wbg_set_f975102236d3c502: __wbg_set_f975102236d3c502, __wbg_get_5419cf6b954aa11d: __wbg_get_5419cf6b954aa11d, __wbg_length_f217bbbf7e8e4df4: __wbg_length_f217bbbf7e8e4df4, __wbg_new_034f913e7636e987: __wbg_new_034f913e7636e987, __wbindgen_is_function: __wbindgen_is_function, __wbg_new_7a87a0376e40533b: __wbg_new_7a87a0376e40533b, __wbg_next_13b477da1eaa3897: __wbg_next_13b477da1eaa3897, __wbg_next_b06e115d1b01e10b: __wbg_next_b06e115d1b01e10b, __wbg_done_983b5ffcaec8c583: __wbg_done_983b5ffcaec8c583, __wbg_value_2ab8a198c834c26a: __wbg_value_2ab8a198c834c26a, __wbg_iterator_695d699a44d6234c: __wbg_iterator_695d699a44d6234c, __wbg_get_ef828680c64da212: __wbg_get_ef828680c64da212, __wbg_call_a9ef466721e824f2: __wbg_call_a9ef466721e824f2, __wbg_new_e69b5f66fda8f13c: __wbg_new_e69b5f66fda8f13c, __wbg_set_425e70f7c64ac962: __wbg_set_425e70f7c64ac962, __wbg_from_91a67a5f04c98a54: __wbg_from_91a67a5f04c98a54, __wbg_isArray_6f3b47f09adb61b5: __wbg_isArray_6f3b47f09adb61b5, __wbg_instanceof_ArrayBuffer_74945570b4a62ec7: __wbg_instanceof_ArrayBuffer_74945570b4a62ec7, __wbg_set_277a63e77c89279f: __wbg_set_277a63e77c89279f, __wbg_isSafeInteger_b9dff570f01a9100: __wbg_isSafeInteger_b9dff570f01a9100, __wbg_entries_c02034de337d3ee2: __wbg_entries_c02034de337d3ee2, __wbg_buffer_ccaed51a635d8a2d: __wbg_buffer_ccaed51a635d8a2d, __wbg_newwithbyteoffsetandlength_7e3eb787208af730: __wbg_newwithbyteoffsetandlength_7e3eb787208af730, __wbg_new_fec2611eb9180f95: __wbg_new_fec2611eb9180f95, __wbg_set_ec2fcf81bc573fd9: __wbg_set_ec2fcf81bc573fd9, __wbg_length_9254c4bd3b9f23c4: __wbg_length_9254c4bd3b9f23c4, __wbg_instanceof_Uint8Array_df0761410414ef36: __wbg_instanceof_Uint8Array_df0761410414ef36, __wbg_new_abda76e883ba8a5f: __wbg_new_abda76e883ba8a5f, __wbg_stack_658279fe44541cf6: __wbg_stack_658279fe44541cf6, __wbg_error_f851667af71bcfc6: __wbg_error_f851667af71bcfc6, __wbindgen_bigint_get_as_i64: __wbindgen_bigint_get_as_i64, __wbindgen_debug_string: __wbindgen_debug_string, __wbindgen_throw: __wbindgen_throw, __wbindgen_memory: __wbindgen_memory, __wbindgen_init_externref_table: __wbindgen_init_externref_table } }, __vite__wasmUrl);
const memory = __vite__wasmModule.memory;
const __wbg_urlblocker_free = __vite__wasmModule.__wbg_urlblocker_free;
const urlblocker_new = __vite__wasmModule.urlblocker_new;
const urlblocker_should_ignore = __vite__wasmModule.urlblocker_should_ignore;
const stash_files = __vite__wasmModule.stash_files;
const __wbg_filesprovider_free = __vite__wasmModule.__wbg_filesprovider_free;
const filesprovider_new = __vite__wasmModule.filesprovider_new;
const filesprovider_set_files = __vite__wasmModule.filesprovider_set_files;
const __wbg_csscompiler_free = __vite__wasmModule.__wbg_csscompiler_free;
const start = __vite__wasmModule.start;
const csscompiler_new = __vite__wasmModule.csscompiler_new;
const csscompiler_patch_and_get_demo_dependencies = __vite__wasmModule.csscompiler_patch_and_get_demo_dependencies;
const csscompiler_patch = __vite__wasmModule.csscompiler_patch;
const csscompiler_get_delta_rules = __vite__wasmModule.csscompiler_get_delta_rules;
const csscompiler_to_css = __vite__wasmModule.csscompiler_to_css;
const __wbindgen_malloc = __vite__wasmModule.__wbindgen_malloc;
const __wbindgen_realloc = __vite__wasmModule.__wbindgen_realloc;
const __wbindgen_export_2 = __vite__wasmModule.__wbindgen_export_2;
const __externref_table_dealloc = __vite__wasmModule.__externref_table_dealloc;
const __wbindgen_exn_store = __vite__wasmModule.__wbindgen_exn_store;
const __externref_table_alloc = __vite__wasmModule.__externref_table_alloc;
const __wbindgen_free = __vite__wasmModule.__wbindgen_free;
const __wbindgen_start = __vite__wasmModule.__wbindgen_start;

const wasm = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    __externref_table_alloc,
    __externref_table_dealloc,
    __wbg_csscompiler_free,
    __wbg_filesprovider_free,
    __wbg_urlblocker_free,
    __wbindgen_exn_store,
    __wbindgen_export_2,
    __wbindgen_free,
    __wbindgen_malloc,
    __wbindgen_realloc,
    __wbindgen_start,
    csscompiler_get_delta_rules,
    csscompiler_new,
    csscompiler_patch,
    csscompiler_patch_and_get_demo_dependencies,
    csscompiler_to_css,
    filesprovider_new,
    filesprovider_set_files,
    memory,
    start,
    stash_files,
    urlblocker_new,
    urlblocker_should_ignore
}, Symbol.toStringTag, { value: 'Module' }));

__wbg_set_wasm(wasm);
__wbindgen_start();

export { CSSCompiler, FilesProvider, UrlBlocker, __wbg_String_b9412f8799faab3e, __wbg_buffer_ccaed51a635d8a2d, __wbg_call_a9ef466721e824f2, __wbg_debug_a0b6c2c5ac9a4bfd, __wbg_done_983b5ffcaec8c583, __wbg_entries_c02034de337d3ee2, __wbg_error_4d17c5bb1ca90c94, __wbg_error_f851667af71bcfc6, __wbg_from_91a67a5f04c98a54, __wbg_get_5419cf6b954aa11d, __wbg_get_ef828680c64da212, __wbg_getwithrefkey_edc2c8960f0f1191, __wbg_info_1c7fba7da21072d1, __wbg_instanceof_ArrayBuffer_74945570b4a62ec7, __wbg_instanceof_Uint8Array_df0761410414ef36, __wbg_isArray_6f3b47f09adb61b5, __wbg_isSafeInteger_b9dff570f01a9100, __wbg_iterator_695d699a44d6234c, __wbg_length_9254c4bd3b9f23c4, __wbg_length_f217bbbf7e8e4df4, __wbg_log_4de37a0274d94769, __wbg_new_034f913e7636e987, __wbg_new_7a87a0376e40533b, __wbg_new_abda76e883ba8a5f, __wbg_new_e69b5f66fda8f13c, __wbg_new_fec2611eb9180f95, __wbg_newwithbyteoffsetandlength_7e3eb787208af730, __wbg_next_13b477da1eaa3897, __wbg_next_b06e115d1b01e10b, __wbg_set_277a63e77c89279f, __wbg_set_425e70f7c64ac962, __wbg_set_ec2fcf81bc573fd9, __wbg_set_f975102236d3c502, __wbg_set_wasm, __wbg_stack_658279fe44541cf6, __wbg_value_2ab8a198c834c26a, __wbg_warn_2e2787d40aad9a81, __wbindgen_as_number, __wbindgen_bigint_from_u64, __wbindgen_bigint_get_as_i64, __wbindgen_boolean_get, __wbindgen_debug_string, __wbindgen_error_new, __wbindgen_in, __wbindgen_init_externref_table, __wbindgen_is_bigint, __wbindgen_is_function, __wbindgen_is_object, __wbindgen_is_string, __wbindgen_is_undefined, __wbindgen_jsval_eq, __wbindgen_jsval_loose_eq, __wbindgen_memory, __wbindgen_number_get, __wbindgen_number_new, __wbindgen_string_get, __wbindgen_string_new, __wbindgen_throw, stash_files$1 as stash_files };
